@@ -363,7 +363,7 @@ class Timestamp(Primitive):
             raise ValidationError('expected timestamp, got %s'
                                   % generic_type_name(val))
         elif val.tzinfo is not None and \
-                        val.tzinfo.utcoffset(val).total_seconds() != 0:
+                val.tzinfo.utcoffset(val).total_seconds() != 0:
             raise ValidationError('timestamp should have either a UTC '
                                   'timezone or none set at all')
         return val
@@ -408,6 +408,26 @@ class List(Composite):
         return [self.item_validator.validate(item) for item in val]
 
 
+class Map(Composite):
+    """Assumes map keys and values are homogeneous with respect to types."""
+
+    def __init__(self, key_validator, value_validator):
+        """
+        Every Map key/value pair will be validated with item_validator.
+        key validators must be a subclass of a String validator
+        """
+        self.key_validator = key_validator
+        self.value_validator = value_validator
+
+    def validate(self, val):
+        if not isinstance(val, dict):
+            raise ValidationError('%r is not a valid dict' % val)
+        return {
+            self.key_validator.validate(key):
+                self.value_validator.validate(value) for key, value in val.items()
+        }
+
+
 class Struct(Composite):
 
     def __init__(self, definition):
@@ -423,6 +443,7 @@ class Struct(Composite):
                     field_name: Name of the field (str).
                     validator: Validator object.
         """
+        super(Struct, self).__init__()
         self.definition = definition
 
     def validate(self, val):
@@ -477,7 +498,9 @@ class StructTree(Struct):
     struct, but does not do any validation specific to the subtype.
     """
 
-    def __init__(self, definition):
+    # See PyCQA/pylint#1043 for why this is disabled; this should show up
+    # as a usless-suppression (and can be removed) once a fix is released
+    def __init__(self, definition):  # pylint: disable=useless-super-delegation
         super(StructTree, self).__init__(definition)
 
 
